==> haskell-storable-tuple-0.0.3.3-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-6PnkiQ4W4u67iX1gR0JnP6
key: storable-tuple-0.0.3.3-6PnkiQ4W4u67iX1gR0JnP6
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: d75f78356a2b75eca371b8534a3dd55d
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.4.3/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-6PnkiQ4W4u67iX1gR0JnP6
depends:
    base-4.11.1.0 base-orphans-0.8-3sF6oREckV1L10hzXC2CHH
    storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-3sF6oREckV1L10hzXC2CHH=070878b14ffeb7fb78d1dad8024b95cb
             storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r=1abdd9ecf110b7cfea207dac4d624762
             utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=632b3d47f82599a1155bed59f183b750
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-Hd5lrZwOnvv9ipn88KYyT6
key: storable-tuple-0.0.3.3-Hd5lrZwOnvv9ipn88KYyT6
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: 601717d90b603fde5157e61fdf9d8131
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.4.3/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-Hd5lrZwOnvv9ipn88KYyT6
depends:
    base-4.11.1.0 base-orphans-0.8-4sD00YChBlrBgDwkujHWZz
    storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-4sD00YChBlrBgDwkujHWZz=0dd735d891c827017f35adf5b579ce37
             storable-record-0.0.4-2l7uejmJzlT83sZU72ZZ5r=1abdd9ecf110b7cfea207dac4d624762
             utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=632b3d47f82599a1155bed59f183b750
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
